==> ExternalSiteCatalog-1.1.2.tgz: ExternalSiteCatalog/tests/externalsitecatalogtestcase.py <==
# -*- coding: utf-8 -*-
## ExternalSiteCatalog
## Index and search external sites in a Plone site
## Copyright (C)2006 Ingeniweb

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; see the file COPYING. If not, write to the
## Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
"""
"""

__author__ = 'Maik Rder <maik.roeder@ingeniweb.com>'
__docformat__ = 'restructuredtext'

from Products.CMFQuickInstallerTool.QuickInstallerTool import AlreadyInstalled
from Products.Archetypes.tests.atsitetestcase import ATSiteTestCase
from Products.PloneTestCase.setup import portal_name
from Testing import ZopeTestCase
import time
from AccessControl.SecurityManagement import newSecurityManager
from Products.PloneTestCase.setup import portal_owner
from Products.CMFCore.utils import getToolByName
from AccessControl.SecurityManagement import noSecurityManager

from Products.Archetypes import transaction

ZopeTestCase.installProduct('PloneMaintenance')
ZopeTestCase.installProduct('ExternalSiteCatalog')

class ExternalSiteCatalogTestCase(ATSiteTestCase):
    """External Site Catalog test"""
    def afterSetUp(self):
        # Remove Tasks
        ids=self.portal.portal_maintenance.tasks.objectIds()
        self.portal.portal_maintenance.tasks.manage_delObjects(ids)
        # Clear Catalog
        self.portal.portal_externalcatalog.manage_catalogClear()
        
    def beforeTearDown(self):
        self.logout()

def setupESC(app, id=portal_name, quiet=False):
    transaction.begin()
    _start = time.time()
    portal = app[id]
    if not quiet: ZopeTestCase._print('Adding ExternalSiteCatalog ... ')

    # login as manager
    user = app.acl_users.getUserById(portal_owner).__of__(app.acl_users)
    newSecurityManager(None, user)
    # add ATCT
    qi = getToolByName(portal, 'portal_quickinstaller')
    try:
        qi.installProduct('PloneMaintenance')
    except AlreadyInstalled:
        # EAFP = easier ask for forgiveness than permission
        if not quiet: ZopeTestCase._print('PloneMaintenance already installed ...\n')
    try:
        qi.installProduct('ExternalSiteCatalog')
    except AlreadyInstalled:
        # EAFP = easier ask for forgiveness than permission
        if not quiet: ZopeTestCase._print('ExternalSiteCatalog already installed ...\n')
    # Log out
    noSecurityManager()
    transaction.commit()
    if not quiet: ZopeTestCase._print('done (%.3fs)\n' % (time.time()-_start,))

app = ZopeTestCase.app()
setupESC(app)
ZopeTestCase.close(app)

==> ExternalSiteCatalog-1.2.0.tgz: ExternalSiteCatalog/tests/externalsitecatalogtestcase.py <==
# -*- coding: utf-8 -*-
## ExternalSiteCatalog
## Index and search external sites in a Plone site
## Copyright (C)2006 Ingeniweb

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; see the file COPYING. If not, write to the
## Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
"""
"""

__author__ = 'Maik Rder <maik.roeder@ingeniweb.com>'
__docformat__ = 'restructuredtext'

from Products.CMFQuickInstallerTool.QuickInstallerTool import AlreadyInstalled
from Products.Archetypes.tests.atsitetestcase import ATSiteTestCase
from Products.PloneTestCase.setup import portal_name
from Testing import ZopeTestCase
import time
from AccessControl.SecurityManagement import newSecurityManager
from Products.PloneTestCase.setup import portal_owner
from Products.CMFCore.utils import getToolByName
from AccessControl.SecurityManagement import noSecurityManager

from Products.CMFPlone.utils import transaction

ZopeTestCase.installProduct('PloneMaintenance')
ZopeTestCase.installProduct('ExternalSiteCatalog')

class ExternalSiteCatalogTestCase(ATSiteTestCase):
    """External Site Catalog test"""
    def afterSetUp(self):
        # Remove Tasks
        ids=self.portal.portal_maintenance.tasks.objectIds()
        self.portal.portal_maintenance.tasks.manage_delObjects(ids)
        # Clear Catalog
        self.portal.portal_externalcatalog.manage_catalogClear()
        
    def beforeTearDown(self):
        self.logout()

def setupESC(app, id=portal_name, quiet=False):
    transaction.begin()
    _start = time.time()
    portal = app[id]
    if not quiet: ZopeTestCase._print('Adding ExternalSiteCatalog ... ')

    # login as manager
    user = app.acl_users.getUserById(portal_owner).__of__(app.acl_users)
    newSecurityManager(None, user)
    # add ATCT
    qi = getToolByName(portal, 'portal_quickinstaller')
    try:
        qi.installProduct('PloneMaintenance')
    except AlreadyInstalled:
        # EAFP = easier ask for forgiveness than permission
        if not quiet: ZopeTestCase._print('PloneMaintenance already installed ...\n')
    try:
        qi.installProduct('ExternalSiteCatalog')
    except AlreadyInstalled:
        # EAFP = easier ask for forgiveness than permission
        if not quiet: ZopeTestCase._print('ExternalSiteCatalog already installed ...\n')
    # Log out
    noSecurityManager()
    transaction.commit()
    if not quiet: ZopeTestCase._print('done (%.3fs)\n' % (time.time()-_start,))

app = ZopeTestCase.app()
setupESC(app)
ZopeTestCase.close(app)
